@@ -1,7 +1,7 @@
 #
-# $Id: RequestArgs.pl,v 14.1 2000/08/15 20:51:30 wpm Exp $
+# $Id: RequestArgs.pl,v 16.2 2001/01/05 21:43:39 wpm Exp $
 #
-# (c) 1999, 2000 Morgan Stanley Dean Witter and Co.
+# (c) 1999-2001 Morgan Stanley Dean Witter and Co.
 # See ..../src/LICENSE for terms of distribution.
 #
 
@@ -43,6 +43,11 @@ package MQSeries::Command::MQSC;
     NamelistName		=> 1,
    },
 
+   ResetQueueStatistics =>
+   {
+    QName                       => 1,
+   },
+
   );
 
 1;
