@@ -1,8 +1,8 @@
 #!/ms/dist/perl5/bin/perl5.005-thread
 #
-# $Id: reply.pl,v 14.1 2000/08/15 20:52:03 wpm Exp $
+# $Id: reply.pl,v 16.2 2001/01/05 21:46:11 wpm Exp $
 #
-# (c) 1999, 2000 Morgan Stanley Dean Witter and Co.
+# (c) 1999-2001 Morgan Stanley Dean Witter and Co.
 # See ..../src/LICENSE for terms of distribution.
 #
 
@@ -46,7 +46,7 @@ while ( 1 ) {
        Wait	=> $::pollrate,
       ) || die "Error occured while waiting for requests\n";
 
-    if ( $::requestq->Reason() == &MQRC_NO_MSG_AVAILABLE ) {
+    if ( $::requestq->Reason() == MQRC_NO_MSG_AVAILABLE ) {
 	print "Timed out waiting for requests.  Retrying...\n";
 	next;
     } 
